@@ -1,7 +1,6 @@
-# -*- coding: UTF-8 -*-
-# @Time    : 2020/10/22
-# @Author  : xiangyuejia@qq.com
+# BASIC FUNCTION
 from aitool.basic_function.basic import split_dict
+from aitool.basic_function.basic import replace_char
 
 from aitool.basic_function.file import file_exist as file_exist
 from aitool.basic_function.file import dump_json as dump_json
@@ -52,3 +51,7 @@ from aitool.task_customized.ip_enhance.filter import delete_nested_text
 from aitool.task_customized.ip_enhance.filter import select_nested_text
 from aitool.task_customized.ip_enhance.filter import is_sub_ip
 from aitool.task_customized.ip_enhance.filter import get_core_ip
+
+
+# NLP FUNCTION
+from aitool.nlp.basic.split_sentence import split_sentence
